<?php
/**
 * The WP Business functions and definitions
 *
 * @package The WP Business
 */
/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'the_wp_business_setup' ) ) :

 
/* Breadcrumb Begin */
function the_wp_business_the_breadcrumb() {
	if (!is_home()) {
		echo '<a href="';
			echo esc_url( home_url() );
		echo '">';
			bloginfo('name');
		echo "</a> ";
		if (is_category() || is_single()) {
			the_category(',');
			if (is_single()) {
				echo "<span> ";
					the_title();
				echo "</span> ";
			}
		} elseif (is_page()) {
			the_title();
		}
	}
}

/* Theme Setup */
function the_wp_business_setup() {

	$GLOBALS['content_width'] = apply_filters( 'the_wp_business_content_width', 640 );
	
	load_theme_textdomain( 'the-wp-business', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('the-wp-business-homepage-thumb',240,145,true);
	
    register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'the-wp-business' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', the_wp_business_font_url() ) );
	// Theme Activation Notice
	global $pagenow;
	
	if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
		add_action( 'admin_notices', 'the_wp_business_activation_notice' );
	}
}
endif;
add_action( 'after_setup_theme', 'the_wp_business_setup' );

// Notice after Theme Activation
function the_wp_business_activation_notice() {
	echo '<div class="notice notice-success is-dismissible welcome">';
		echo '<h3>'. esc_html__( 'Greetings from Themeglance!!', 'the-wp-business' ) .'</h3>';
		echo '<p>'. esc_html__( 'A heartful thank you for choosing Themeglance. We promise to deliver only the best to you. Please proceed towards welcome section to get started.', 'the-wp-business' ) .'</p>';
		echo '<p><a href="'. esc_url( admin_url( 'themes.php?page=the_wp_business_guide' ) ) .'" class="button button-primary">'. esc_html__( 'About Theme', 'the-wp-business' ) .'</a></p>';
	echo '</div>';
}

/* Theme Widgets Setup */
function the_wp_business_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'the-wp-business' ),
		'description'   => __( 'Appears on blog page sidebar', 'the-wp-business' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'the-wp-business' ),
		'description'   => __( 'Appears on page sidebar', 'the-wp-business' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Third Sidebar', 'the-wp-business' ),
		'description'   => __( 'Appears on page sidebar', 'the-wp-business' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'the-wp-business' ),
		'description'   => __( 'Appears on footer', 'the-wp-business' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'the-wp-business' ),
		'description'   => __( 'Appears on footer', 'the-wp-business' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'the-wp-business' ),
		'description'   => __( 'Appears on footer', 'the-wp-business' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'the-wp-business' ),
		'description'   => __( 'Appears on footer', 'the-wp-business' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'the_wp_business_widgets_init' );

/* Theme Font URL */
function the_wp_business_font_url() {
	$font_url = '';
	$font_family = array();
	$font_family[] = 'PT Sans:300,400,600,700,800,900';
	$font_family[] = 'Montserrat:300,400,600,700,800,900';
	$font_family[] = 'Roboto:400,700';

	$query_args = array(
		'family'	=> urlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}
	
/* Theme enqueue scripts */
function the_wp_business_scripts() {
	wp_enqueue_style( 'the-wp-business-font', the_wp_business_font_url(), array() );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.css' );
	wp_enqueue_style( 'the-wp-business-basic-style', get_stylesheet_uri() );
	wp_style_add_data( 'the-wp-business-style', 'rtl', 'replace' );
	wp_enqueue_style( 'the-wp-business-effect', get_template_directory_uri().'/css/effect.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/fontawesome-all.css' );	
	wp_enqueue_style( 'css-nivo-slider', get_template_directory_uri().'/css/nivo-slider.css' );
	wp_enqueue_script( 'jquery-nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	wp_enqueue_script( 'the-wp-business-custom-scripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	wp_enqueue_script( 'jquery-bootstrap', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_style('the-wp-business-ie', get_template_directory_uri().'/css/ie.css', array('the-wp-business-basic-style'));
	wp_style_add_data( 'the-wp-business-ie', 'conditional', 'IE' );
}
add_action( 'wp_enqueue_scripts', 'the_wp_business_scripts' );

/* Theme Credit link */
define('THE_WP_BUSINESS_PRO_THEME_URL','https://www.themesglance.com/premium/business-wordpress-theme/','the-wp-business');
define('THE_WP_BUSINESS_THEME_DOC','https://www.themesglance.com/docs/wp-business/','the-wp-business');
define('THE_WP_BUSINESS_LIVE_DEMO','http://www.themesglance.com/wp-business-theme/','the-wp-business');
define('THE_WP_BUSINESS_FREE_THEME_DOC','https://www.themesglance.com/docs/free-wp-bussiness/','the-wp-business');
define('THE_WP_BUSINESS_SUPPORT','https://wordpress.org/support/theme/the-wp-business/','the-wp-business');
define('THE_WP_BUSINESS_REVIEW','https://www.themesglance.com/support/?view=forum&id=5','the-wp-business');
define('THE_WP_BUSINESS_SITE_URL','https://www.themesglance.com/');

function the_wp_business_credit_link() {
    echo "<a href=".esc_url(THE_WP_BUSINESS_SITE_URL)." target='_blank'>".esc_html__('ThemesGlance','the-wp-business')."</a>";
}

/*radio button sanitization*/

 function the_wp_business_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

/* About Theme. */
require get_template_directory() . '/inc/getting-started/getting-started.php';
/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';
/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';
/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';